sequencetools.negate_absolute_value_of_sequence_elements_at_indices
===================================================================

.. autofunction:: abjad.tools.sequencetools.negate_absolute_value_of_sequence_elements_at_indices.negate_absolute_value_of_sequence_elements_at_indices
